#include <Adafruit_NeoPixel.h>

#define PIN 2   //LEDi NANOya baglayacagimiz pin numarasi
#define Brightness 10 //1 - 10 arasinda parlakligi ayarlayabilirsiniz.
#define Full (255/Brightness)

// Parameter 1 = LED seritteki LEDlerin toplam sayisi
// Parameter 2 = Data ucunu Arduino'da baglayacagimiz pin numarasi
// Parameter 3 = LED pixellerini belirtiyoruz, asagida NeoPixel icin kullanilabilecek olanlari listeledim. WS2812B icin NEO_GRB+NEO_KHZ800 kullaniyoruz:
//   NEO_KHZ800  800 KHz bitstream (most NeoPixel products w/WS2812 LEDs)
//   NEO_KHZ400  400 KHz (classic 'v1' (not v2) FLORA pixels, WS2811 drivers)
//   NEO_GRB     Pixels are wired for GRB bitstream (most NeoPixel products)
//   NEO_RGB     Pixels are wired for RGB bitstream (v1 FLORA pixels, not v2)

Adafruit_NeoPixel strip = Adafruit_NeoPixel(150, PIN, NEO_GRB + NEO_KHZ800);

// DİKKAT: NeoPixel LED'in ariza verme riskini azaltmak icin, + ve - voltaj girisine + ve - uçlarinin dogru oldugunu kontrol ederek 1000 uF kapasitor (kondansator) ekleyin
// LED seridin, ilk LEDinin veri girisine 300 - 500 Ohm direnc ekleyin ve Arduino ile ilk LED arasindaki mesafeyi en aza indirin.
// Voltaj verdikten sonra LED serit baglantisini kesinlikle yapmayin. LED serit veya Arduino zarar gorebilir.

// Degiskenlerimizi tanimliyoruz
unsigned long timeOut=60000; // PIR dedektorun ne zaman hareket algiladigini tutmak icin
int downUp = 0;              // Merdivende yanma yonunun yukari mi asagi mi oldugunu tutmak icin
int lightsopen = 0;          // Eger 1 ise LED ler yaniyor, 0 ise kapali
int alarmPinTop = 3;        // Ust PIR sensor pin no
int alarmPinBottom =4;      // Alt PIR sensor pin no
int alarmValueTop = LOW;    // Ust PIR durumunu tutmak icin LOW hareket yok, HIGH hareket var anlaminda
int alarmValueBottom = LOW; // Alt PIR durumunu tutmak icin LOW hareket yok, HIGH hareket var anlaminda
int LDRSensor = A0;        // LDR foto direnc baglanti pini
int LDRValue = 0;          // LDR foto direnc degerini tutmak icin
int colourArray[350];      // RGB degerini tutmak icin
int change = 1;            // LED beklemedeyken yanip sonmesini ayarlamak icin
int breathe = 0;           // LED beklemedeyken yanip sonmesini ayarlamak icin

void setup() {
   strip.begin();
   strip.show(); // Tum LED'leri kapali olarak ayarliyoruz
   Serial.begin (9600);  // seri baglanti uzerinden debug yapmak icin 
   pinMode(alarmPinTop, INPUT_PULLUP);     // Ust PIR aktif hale getiriyoruz
   pinMode(alarmPinBottom, INPUT_PULLUP);  // Alt PIR aktif hale getiriyoruz
   delay (2000); // 2 saniye PIR'larin algilama moduna gecmesini bekliyoruz. 
   demo();  // Gokkusagi isik seli yapiyoruz
   strip.setBrightness(40); //LED parlakligini burdan ayarlayabilirsiniz
}

void loop() {

     if (timeOut+15700 < millis()) {        // LEDi bekleme durumunda mavi yakip sonduruyoruz.
       uint32_t blue = (0, 0, breathe);
       breathe = breathe + change;
       // 1
       strip.setPixelColor(0, blue);
       strip.setPixelColor(11, blue);
       // 2
       strip.setPixelColor(12, blue);
       strip.setPixelColor(23, blue);
       // 3
       strip.setPixelColor(24, blue);
       strip.setPixelColor(35, blue);
       // 4
       strip.setPixelColor(36, blue);
       strip.setPixelColor(47, blue);
       // 5
       strip.setPixelColor(48, blue);
       strip.setPixelColor(59, blue);
       // 6
       strip.setPixelColor(60, blue);
       strip.setPixelColor(71, blue);
       // 7
       strip.setPixelColor(72, blue);
       strip.setPixelColor(83, blue);
       // 8
       strip.setPixelColor(84, blue);
       strip.setPixelColor(95, blue);
       // 9
       strip.setPixelColor(96, blue);
       strip.setPixelColor(107, blue);
       // 10
       strip.setPixelColor(108, blue);
       strip.setPixelColor(119, blue);
       // 11
       strip.setPixelColor(120, blue);
       strip.setPixelColor(131, blue);
       // 12
       strip.setPixelColor(132, blue);
       strip.setPixelColor(143, blue);
       strip.show();
       if (breathe == 100 || breathe == 0) change = -change;      // 0 = yanmiyor, 100 = parlak yaniyor
       if (breathe == 100 || breathe == 0); delay (25);           // her yanma ve sonmede bekliyoruz
  }
  
  LDRLevel();
  
  if (LDRValue < 300) {        // Ortam karanliksa LEDlerin yanmasini buradan sagliyoruz. Buradaki degeri degistirerek karanlik seviyesini ayarlayabilirsiniz.
    
    alarmValueTop = digitalRead(alarmPinTop);    // Ust PIR durumunu kontrol et hareket var mi
    alarmValueBottom = digitalRead(alarmPinBottom);  // Alt PIR durumunu kontrol et hareket var mi

    Serial.print("LDR Value: ");
    Serial.println(LDRValue);
    
    if (alarmValueTop == HIGH && downUp != 2 && lightsopen == 0)  {      // Ust PIR'dan hareket algilaninca, LEDlerin yanmadigini ve isik yonunu kontrol ediyoruz.
      timeOut=millis();  // Hareketin algilandigi zamani aliyoruz.
      downUp = 1;
      lightsopen = 1;
      topdown();         // LEDleri yukaridan asagiya yakiyoruz.
    }
 
    if (alarmValueBottom == HIGH && downUp != 1 && lightsopen == 0)  {    // Alt PIR'dan hareket algilaninca, LEDlerin yanmadigini ve isik yonunu kontrol ediyoruz.
      timeOut=millis();    // Hareketin algilandigi zamani aliyoruz.
      downUp = 2;
      lightsopen = 1;
      bottomup();         // LEDleri asagidan yukariya yakiyoruz.
    }

  }
  
  if (timeOut+10000 < millis() && timeOut+15000 < millis()) {    //belirlenen sure sonunda LEDleri sonduruyoruz.
       if (downUp == 1) {
          colourWipeDown(strip.Color(0, 0, 0), 200); // LEDleri kapat
       }
       if (downUp == 2)  {
        colourWipeUp(strip.Color(0, 0, 0), 200);   // LEDleri kapat
       }
      downUp = 0;
      lightsopen = 0;
    }
            
}

 void topdown() {
    Serial.println ("Ust PIR hareket algiladi");                  // debug ekranina hangi PIR onu yaz
    for (uint16_t j = 0; j < 12; j++){
      int start = (strip.numPixels()-6)/12 *j;
      Serial.println(j);
      int i = start;
      strip.setPixelColor(i, strip.Color(255, 0, 0));  // kirmizi
      strip.setPixelColor(i+1, strip.Color(0, 255, 0));  // yesil
      strip.setPixelColor(i+2, strip.Color(255, 255, 0));  // sari
      strip.setPixelColor(i+3, strip.Color(0, 255, 255));  // cyan
      strip.setPixelColor(i+4, strip.Color(255, 0, 255));  // magenta
      strip.setPixelColor(i+5, strip.Color(0, 0, 255));  // mavi
      strip.setPixelColor(i+6, strip.Color(255, 0, 0));  // kirmizi
      strip.setPixelColor(i+7, strip.Color(0, 255, 0));  // yesil
      strip.setPixelColor(i+8, strip.Color(255, 255, 0));  // sari
      strip.setPixelColor(i+9, strip.Color(0, 255, 255));  // cyan
      strip.setPixelColor(i+10, strip.Color(255, 0, 255));  // magenta
      strip.setPixelColor(i+11, strip.Color(0, 0, 255));  // mavi
      strip.show();  
      delay(200);
    }  
 }



 void bottomup() {
    Serial.println ("Alt PIR hareket algiladi");            // debug ekranina hangi PIR onu yaz
    for (uint16_t j = 12; j > 0; j--){
      int start = ((strip.numPixels()-6)/12 *j)-1;
      Serial.println(start);
      Serial.println(j);
      int i = start;
      strip.setPixelColor(i, strip.Color(255, 0, 0));  // kirmizi
      strip.setPixelColor(i-1, strip.Color(0, 255, 0));  // yesil
      strip.setPixelColor(i-2, strip.Color(255, 255, 0));  // sari
      strip.setPixelColor(i-3, strip.Color(0, 255, 255));  // cyan
      strip.setPixelColor(i-4, strip.Color(255, 0, 255));  // magenta
      strip.setPixelColor(i-5, strip.Color(0, 0, 255));  // mavi
      strip.setPixelColor(i-6, strip.Color(255, 0, 0));  // kirmizi
      strip.setPixelColor(i-7, strip.Color(0, 255, 0));  // yesil
      strip.setPixelColor(i-8, strip.Color(255, 255, 0));  // sari
      strip.setPixelColor(i-9, strip.Color(0, 255, 255));  // cyan
      strip.setPixelColor(i-10, strip.Color(255, 0, 255));  // magenta
      strip.setPixelColor(i-11, strip.Color(0, 0, 255));  // mavi
      strip.show();
      delay(200);
  }  

 }

 // Fade light each step strip
 void colourWipeDown(uint32_t c, uint16_t wait) {

  for (uint16_t j = 0; j < 12; j++){
  int start = strip.numPixels()/12 *j;
  Serial.println(j);
    
        for (uint16_t i = start; i < start + 12; i++){
        	strip.setPixelColor(i, c);
        }
     	strip.show();  
  delay(wait);
  }
}


void clearStrip(){
  for (int l=0; l<strip.numPixels(); l++){
    strip.setPixelColor(l, (0,0,0));
  }
       
}
 // Fade light each step strip
 void colourWipeUp(uint32_t c, uint16_t wait) {

   for (uint16_t j = 12; j > 0; j--){
   int start = strip.numPixels()/12 *j;
   Serial.println(j);
      //start = start-1;
          for (uint16_t i = start; i > start - 12; i--){
    	    strip.setPixelColor(i-1, c);
         }
          strip.show();
  delay(wait);
  }  
  
 }

void LDRLevel(){
  LDRValue = analogRead(LDRSensor);
  if (LDRValue > 1000) { LDRValue = 1000; }
  float level = (LDRValue / 1000)*100;
  
  if (level<0){
    level = 0;
  }
}
 
 void demo() {
  rainbowCycle(10,2);//10 gokkusagi dongusu
  colorWipe(0,0);//Siyah renge ayarliyoruz
 }

 void rainbowCycle(uint8_t sets, uint8_t wait) {
  uint16_t i, j;
  for(j=0; j<256*sets; j++) { //cycles of all colors on wheel
    for(i=0; i< strip.numPixels(); i++) {
      strip.setPixelColor(strip.numPixels()-i-1, Wheel(((i * 256 / strip.numPixels()) + j) & 255));
    }
    strip.show();
    delay(wait);
  }
}
 
// LED rengini belirlemek için 0 to 255 arasinda bir deger girmek gerekiyor.
// Renk gecisleri r - g - b - r seklindedir.
uint32_t Wheel(byte WheelPos) {
  if(WheelPos < 85) {
   return strip.Color((WheelPos * 3)/Brightness, (255 - WheelPos * 3)/Brightness, 0);
  } else if(WheelPos < 170) {
   WheelPos -= 85;
   return strip.Color((255 - WheelPos * 3)/Brightness, 0, (WheelPos * 3)/Brightness);
  } else {
   WheelPos -= 170;
   return strip.Color(0,(WheelPos * 3)/Brightness, (255 - WheelPos * 3)/Brightness);
  }
}

void colorWipe(uint32_t c, uint8_t wait) {
  for(uint16_t i=0; i<strip.numPixels(); i++) {
      strip.setPixelColor(i, c);
      strip.show();
      if (wait>0) { delay(wait); }
  }
}
